==========
Exceptions
==========

This filters can be helpful for handling errors from the text messages.

.. autoclass:: litegram.filters.exception.ExceptionTypeFilter
    :members:
    :member-order: bysource
    :undoc-members: False

.. autoclass:: litegram.filters.exception.ExceptionMessageFilter
    :members:
    :member-order: bysource
    :undoc-members: False

Allowed handlers
================

Allowed update types for this filters:

- :code:`error`
